==> google-cloud-sdk-474.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/backup_dr/backup_plan_associations/trigger_backup.py <==
# -*- coding: utf-8 -*- #
# Copyright 2024 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create an on-demand backup for a resource."""


from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from apitools.base.py import exceptions as apitools_exceptions
from googlecloudsdk.api_lib.backupdr import util
from googlecloudsdk.api_lib.backupdr.backup_plan_associations import BackupPlanAssociationsClient
from googlecloudsdk.api_lib.util import exceptions
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.backupdr import flags
from googlecloudsdk.core import log


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class TriggerBackup(base.Command):
  """Create an on-demand backup for a resource."""

  detailed_help = {
      'BRIEF': 'Create an on-demand backup.',
      'DESCRIPTION': (
          '{description} Trigger an on demand backup for the given backup rule.'
      ),
      'EXAMPLES': """\
        To trigger an on demand backup for a backup pla association `sample-bpa` in project `sample-project` and location `us-central1` with backup plan `sample-backup-rule`, run:

          $ {command} sample-bpa --project=sample-project --location=us-central1 --backup-rule=sample-backup-rule
        """,
  }

  @staticmethod
  def Args(parser):
    """Specifies additional command flags.

    Args:
      parser: argparse.Parser: Parser object for command line inputs.
    """
    base.ASYNC_FLAG.AddToParser(parser)
    base.ASYNC_FLAG.SetDefault(parser, True)
    flags.AddTriggerBackupFlags(parser)

  def Run(self, args):
    """Constructs and sends request.

    Args:
      args: argparse.Namespace, An object that contains the values for the
        arguments specified in the .Args() method.

    Returns:
      ProcessHttpResponse of the request made.
    """
    client = BackupPlanAssociationsClient()
    is_async = args.async_

    backup_plan_association = args.CONCEPTS.backup_plan_association.Parse()
    backup_rule = args.backup_rule_id

    try:
      operation = client.TriggerBackup(backup_plan_association, backup_rule)
    except apitools_exceptions.HttpError as e:
      raise exceptions.HttpException(e, util.HTTP_ERROR_FORMAT)
    if is_async:
      # pylint: disable=protected-access
      # none of the log.CreatedResource, log.DeletedResource etc. matched
      log._PrintResourceChange(
          'on demand backup',
          operation.name,
          kind='backup plan association',
          is_async=True,
          details=(
              'Run the [gcloud backup-dr operations describe] command '
              'to check the status of this operation.'
          ),
          failed=None,
      )
      return

    client.WaitForOperation(
        operation_ref=client.GetOperationRef(operation),
        message=(
            'On demand backup in progress [{}]. (This operation usually takes'
            ' less than 15 minutes but could take up to 8 hours.)'.format(
                backup_plan_association.RelativeName()
            )
        ),
    )
    # pylint: disable=protected-access
    # none of the log.CreatedResource, log.DeletedResource etc. matched
    log._PrintResourceChange(
        'on demand backup',
        backup_plan_association.RelativeName(),
        kind='backup plan association',
        is_async=False,
        details=None,
        failed=None,
        operation_past_tense='on demand backup done for',
    )

    return

==> google-cloud-sdk-481.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/backup_dr/backup_plan_associations/trigger_backup.py <==
# -*- coding: utf-8 -*- #
# Copyright 2024 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create an on-demand backup."""


from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from apitools.base.py import exceptions as apitools_exceptions
from googlecloudsdk.api_lib.backupdr import util
from googlecloudsdk.api_lib.backupdr.backup_plan_associations import BackupPlanAssociationsClient
from googlecloudsdk.api_lib.util import exceptions
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.backupdr import flags
from googlecloudsdk.core import log


@base.Hidden
@base.DefaultUniverseOnly
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class TriggerBackup(base.Command):
  """Create an on-demand backup for a resource."""

  detailed_help = {
      'BRIEF': 'Create an on-demand backup.',
      'DESCRIPTION': (
          '{description} Trigger an on demand backup for the given backup rule.'
      ),
      'EXAMPLES': """\
        To trigger an on demand backup for a backup plan association `sample-bpa` in project `sample-project` and location `us-central1` with backup rule `sample-backup-rule`, run:

          $ {command} sample-bpa --project=sample-project --location=us-central1 --backup-rule-id=sample-backup-rule
        """,
  }

  @staticmethod
  def Args(parser):
    """Specifies additional command flags.

    Args:
      parser: argparse.Parser: Parser object for command line inputs.
    """
    base.ASYNC_FLAG.AddToParser(parser)
    base.ASYNC_FLAG.SetDefault(parser, True)
    flags.AddTriggerBackupFlags(parser)

  def Run(self, args):
    """Constructs and sends request.

    Args:
      args: argparse.Namespace, An object that contains the values for the
        arguments specified in the .Args() method.

    Returns:
      ProcessHttpResponse of the request made.
    """
    client = BackupPlanAssociationsClient()
    is_async = args.async_

    backup_plan_association = args.CONCEPTS.backup_plan_association.Parse()
    backup_rule = args.backup_rule_id

    try:
      operation = client.TriggerBackup(backup_plan_association, backup_rule)
    except apitools_exceptions.HttpError as e:
      raise exceptions.HttpException(e, util.HTTP_ERROR_FORMAT)
    if is_async:
      # pylint: disable=protected-access
      # none of the log.CreatedResource, log.DeletedResource etc. matched
      log._PrintResourceChange(
          'on demand backup',
          operation.name,
          kind='backup plan association',
          is_async=True,
          details=(
              'Run the [gcloud backup-dr operations describe] command '
              'to check the status of this operation.'
          ),
          failed=None,
      )
      return

    client.WaitForOperation(
        operation_ref=client.GetOperationRef(operation),
        message=(
            'On demand backup in progress [{}]. (This operation usually takes'
            ' less than 15 minutes but could take up to 8 hours.)'.format(
                backup_plan_association.RelativeName()
            )
        ),
    )
    # pylint: disable=protected-access
    # none of the log.CreatedResource, log.DeletedResource etc. matched
    log._PrintResourceChange(
        'on demand backup',
        backup_plan_association.RelativeName(),
        kind='backup plan association',
        is_async=False,
        details=None,
        failed=None,
        operation_past_tense='on demand backup done for',
    )

    return
